<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package apollo
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function ot_apollo_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	return $classes;
}
add_filter( 'body_class', 'ot_apollo_body_classes' );

if ( version_compare( $GLOBALS['wp_version'], '4.1', '<' ) ) :
	/**
	 * Filters wp_title to print a neat <title> tag based on what is being viewed.
	 *
	 * @param string $title Default title text for current view.
	 * @param string $sep Optional separator.
	 * @return string The filtered title.
	 */
	function ot_apollo_wp_title( $title, $sep ) {
		if ( is_feed() ) {
			return $title;
		}

		global $page, $paged;

		// Add the blog name
		$title .= get_bloginfo( 'name', 'display' );

		// Add the blog description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title .= " $sep $site_description";
		}

		// Add a page number if necessary:
		if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
			$title .= " $sep " . sprintf( __( 'Page %s', 'ot-apollo' ), max( $paged, $page ) );
		}

		return $title;
	}
	add_filter( 'wp_title', 'ot_apollo_wp_title', 10, 2 );

	/**
	 * Title shim for sites older than WordPress 4.1.
	 *
	 * @link https://make.wordpress.org/core/2014/10/29/title-tags-in-4-1/
	 * @todo Remove this function when WordPress 4.3 is released.
	 */
	function ot_apollo_render_title() {
		?>
		<title><?php wp_title( '|', true, 'right' ); ?></title>
		<?php
	}
	add_action( 'wp_head', 'ot_apollo_render_title' );
endif;

function remove_cssjs_ver( $src ) {
    if( strpos( $src, '?ver=' ) )
        $src = remove_query_arg( 'ver', $src );
    return $src;
}
add_filter( 'style_loader_src', 'remove_cssjs_ver', 10, 2 );

function my_post_queries( $query ) {
  // not an admin page and it is the main query
  if (!is_admin() && $query->is_main_query()){

    if(is_tax('section')){
      // show 50 posts on custom taxonomy pages
      $query->set('posts_per_page', 50);
    }
  }
}
add_action( 'pre_get_posts', 'my_post_queries' );



//Read More Button For Excerpt
function apollo_excerpt_read_more_link( $output ) {
	global $post;
	return $output . '<a class="more-link apollo-button" href="'. get_permalink( get_the_ID() ) . '">' . __('Continue Reading &rarr;', 'ot-apollo') . '</a>';
}
add_filter( 'the_excerpt', 'apollo_excerpt_read_more_link' );

function ot_apollo_favicon() {
	
	$favicon = get_theme_mod('favicon', get_template_directory_uri().'/favicon.ico');
	
	echo '<link rel="shortcut icon" href="' . esc_url($favicon) . '" />';
}
add_action('wp_head', 'ot_apollo_favicon', 8);