<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package apollo
 */

if ( ! function_exists( 'ot_apollo_posts_navigation' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 */
function ot_apollo_posts_navigation() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	// Numbered Pagination

		$prev_arrow = is_rtl() ? 'Previous &raquo;' : '&laquo; Previous';
		$next_arrow = is_rtl() ? 'Next &laquo;' : 'Next  &raquo;';
		
		global $wp_query;
		$total = $wp_query->max_num_pages;
		$big = 999999999; // need an unlikely integer
		if( $total > 1 )  {
			 if( !$current_page = get_query_var('paged') )
				 $current_page = 1;
			 if( get_option('permalink_structure') ) {
				 $format = 'page/%#%/';
			 } else {
				 $format = '&paged=%#%';
			 }
			echo paginate_links(array(
				'base'			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format'		=> $format,
				'current'		=> max( 1, get_query_var('paged') ),
				'total' 		=> $total,
				'mid_size'		=> 3,
				'type' 			=> 'list',
				'prev_text'		=> $prev_arrow,
				'next_text'		=> $next_arrow,
			 ) );
	
}
}
endif;

if ( ! function_exists( 'ot_apollo_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function ot_apollo_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation clearfix" role="navigation">
		<h3 class="screen-reader-text"><?php _e( 'Post navigation', 'ot-apollo' ); ?></h3>
		<div class="post-links clearfix">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">Previous Post</span><p>%title</p>', 'Previous post link', 'ot-apollo' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '<span class="meta-nav">Next Post</span><p>%title</p>', 'Next post link',     'ot-apollo' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'ot_apollo_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function ot_apollo_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		_x( 'Posted on %s', 'post date', 'ot-apollo' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		_x( 'by %s', 'post author', 'ot-apollo' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>';

}
endif;


if ( ! function_exists( 'ot_apollo_entry_footer' ) ) :

	function ot_apollo_entry_footer() {
		
		if ( is_single() ) {
		
			echo '<div class="footer-meta">';

			if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
				$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
				if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
					$time_string = '<time class="updated" datetime="%3$s">%4$s</time>';
				}
				$time_string = sprintf( $time_string,
					esc_attr( get_the_date( 'c' ) ),
					esc_html( get_the_date() ),
					esc_attr( get_the_modified_date( 'c' ) ),
					esc_html( get_the_modified_date() )
				);
				printf( '<span class="posted-on">This article was published <span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark">%3$s</a> in </span>',
					esc_html_x( 'Posted on', 'Used before publish date.', 'ot-apollo' ),
					esc_url( get_permalink() ),
					$time_string
				);
			}
			if ( 'post' == get_post_type() ) {

				$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'ot-apollo' ) );
				if ( $categories_list && ot_apollo_categorized_blog() ) {
					printf( '<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
						esc_html_x( 'Categories', 'Used before category names.', 'ot-apollo' ),
						$categories_list
					);
				}
				$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'ot-apollo' ) );
				if ( $tags_list ) {
					printf( ' and tagged: <span class="tags-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
						esc_html_x( 'Tags', 'Used before tag names.', 'ot-apollo' ),
						$tags_list
					);
				}
			}
			if ( is_attachment() && wp_attachment_is_image() ) {
				// Retrieve attachment metadata.
				$metadata = wp_get_attachment_metadata();
				printf( '<span class="full-size-link"><span class="screen-reader-text">%1$s </span><a href="%2$s">%3$s &times; %4$s</a></span>',
					esc_html_x( 'Full size', 'Used before full size attachment link.', 'ot-apollo' ),
					esc_url( wp_get_attachment_url() ),
					$metadata['width'],
					$metadata['height']
				);
			}

			echo '</div>';
	}
		
	}
endif;


if ( ! function_exists( 'the_archive_title' ) ) :
/**
 * Shim for `the_archive_title()`.
 *
 * Display the archive title based on the queried object.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 *
 * @param string $before Optional. Content to prepend to the title. Default empty.
 * @param string $after  Optional. Content to append to the title. Default empty.
 */
function the_archive_title( $before = '', $after = '' ) {
	if ( is_category() ) {
		$title = sprintf( __( 'Category: %s', 'ot-apollo' ), single_cat_title( '', false ) );
	} elseif ( is_tag() ) {
		$title = sprintf( __( 'Tag: %s', 'ot-apollo' ), single_tag_title( '', false ) );
	} elseif ( is_author() ) {
		$title = sprintf( __( 'Author: %s', 'ot-apollo' ), '<span class="vcard">' . get_the_author() . '</span>' );
	} elseif ( is_year() ) {
		$title = sprintf( __( 'Year: %s', 'ot-apollo' ), get_the_date( _x( 'Y', 'yearly archives date format', 'ot-apollo' ) ) );
	} elseif ( is_month() ) {
		$title = sprintf( __( 'Month: %s', 'ot-apollo' ), get_the_date( _x( 'F Y', 'monthly archives date format', 'ot-apollo' ) ) );
	} elseif ( is_day() ) {
		$title = sprintf( __( 'Day: %s', 'ot-apollo' ), get_the_date( _x( 'F j, Y', 'daily archives date format', 'ot-apollo' ) ) );
	} elseif ( is_tax( 'post_format' ) ) {
		if ( is_tax( 'post_format', 'post-format-aside' ) ) {
			$title = _x( 'Asides', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
			$title = _x( 'Galleries', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
			$title = _x( 'Images', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
			$title = _x( 'Videos', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
			$title = _x( 'Quotes', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
			$title = _x( 'Links', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
			$title = _x( 'Statuses', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
			$title = _x( 'Audio', 'post format archive title', 'ot-apollo' );
		} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
			$title = _x( 'Chats', 'post format archive title', 'ot-apollo' );
		}
	} elseif ( is_post_type_archive() ) {
		$title = sprintf( __( 'Archives: %s', 'ot-apollo' ), post_type_archive_title( '', false ) );
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		/* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
		$title = sprintf( __( '%1$s: %2$s', 'ot-apollo' ), $tax->labels->singular_name, single_term_title( '', false ) );
	} else {
		$title = __( 'Archives', 'ot-apollo' );
	}

	/**
	 * Filter the archive title.
	 *
	 * @param string $title Archive title to be displayed.
	 */
	$title = apply_filters( 'get_the_archive_title', $title );

	if ( ! empty( $title ) ) {
		echo $before . $title . $after;
	}
}
endif;

if ( ! function_exists( 'the_archive_description' ) ) :
/**
 * Shim for `the_archive_description()`.
 *
 * Display category, tag, or term description.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 *
 * @param string $before Optional. Content to prepend to the description. Default empty.
 * @param string $after  Optional. Content to append to the description. Default empty.
 */
function the_archive_description( $before = '', $after = '' ) {
	$description = apply_filters( 'get_the_archive_description', term_description() );

	if ( ! empty( $description ) ) {
		/**
		 * Filter the archive description.
		 *
		 * @see term_description()
		 *
		 * @param string $description Archive description to be displayed.
		 */
		echo $before . $description . $after;
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function ot_apollo_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'ot_apollo_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'ot_apollo_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so ot_apollo_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so ot_apollo_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in ot_apollo_categorized_blog.
 */
function ot_apollo_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'ot_apollo_categories' );
}
add_action( 'edit_category', 'ot_apollo_category_transient_flusher' );
add_action( 'save_post',     'ot_apollo_category_transient_flusher' );

/* Custom Comment Output */
function ot_apollo_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class('clearfix'); ?> id="li-comment-<?php comment_ID() ?>">
<div class="comment-gravatar">
            <?php echo get_avatar( $comment->comment_author_email, 70 ); ?>
          </div>
		<div class="comment-block" id="comment-<?php comment_ID(); ?>">
			<div class="comment-info">
				<div class="comment-apollo vcard clearfix">
					
          
					<div class="comment-meta commentmetadata">
						<h5><?php comment_author_link() ?></h5>
					</div>
				</div>
			</div><!-- comment info -->

			<div class="comment-text">
				<?php comment_text() ?>

				<div class="comment-bottom clearfix">
					<p class="reply">
						<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ) ?>
					</p>
					<span><?php edit_comment_link(__('Edit', 'ot-apollo'),'&nbsp; &middot; &nbsp;', '' ) ?></span>
					<a class="comment-time" href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ) ?>"><?php printf(__('%1$s at %2$s', 'ot-apollo'), get_comment_date(),  get_comment_time()) ?></a>
				</div>
			</div><!-- comment text -->

			<?php if ($comment->comment_approved == '0') : ?>
				<em class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'ot-apollo') ?></em>
			<?php endif; ?>
		</div></li>
<?php }