<?php
/*
Plugin Name: Olympus Toolkit
Plugin URI: http://olympusthemes.com/toolkit
Description: Adds shortcode functionality and widgets (Twitter, Facebook, Newsletter, Video, Social & more).
Author: Olympus Themes
Author URI: http://olympusthemes.com
Version: 1.0.2
Text Domain: olympus-toolkit
License: GPL version 2 or later - http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
*/

if ( ! defined( 'ABSPATH' ) ) { 
    exit; // Exit if accessed directly
}

// Main shortcode functions
require_once( plugin_dir_path(__FILE__) . '/shortcodes/shortcode-functions.php');
require_once( plugin_dir_path(__FILE__) . '/settings/settings-api.php');

// Adds mce buttons to post editor
require_once( plugin_dir_path(__FILE__) . '/shortcodes/mce/olympus_shortcodes_tinymce.php');

/**
 * Load Widgets
 */
require_once( plugin_dir_path(__FILE__) . '/widgets/video-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/twitter-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/social-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/newsletter-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/facebook-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/dribbble-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/flickr-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/author-widget.php');
require_once( plugin_dir_path(__FILE__) . '/widgets/featured-posts-widget.php'); 

if( !function_exists ('olympus_shortcodes_scripts') ) :
	function olympus_shortcodes_scripts() {

		$scripts_dir = plugin_dir_url( __FILE__ );

		// Make sure jquery is loaded
		wp_enqueue_script( 'jquery' );

		// Register scripts
		wp_register_script( 'olympus_tabs', $scripts_dir . 'shortcodes/js/olympus_tabs.js', array ( 'jquery', 'jquery-ui-tabs'), '1.0', true );
		wp_register_script( 'rslides', $scripts_dir . 'shortcodes/js/responsiveslides.min.js', 'jquery', '1.0', true );	
		wp_register_script( 'olympus_toggle', $scripts_dir . 'shortcodes/js/olympus_toggle.js', 'jquery', '1.0', true );
		wp_register_script( 'olympus_accordion', $scripts_dir . 'shortcodes/js/olympus_accordion.js', array ( 'jquery', 'jquery-ui-accordion'), '1.0', true );
		wp_register_script( 'olympus_googlemap',  $scripts_dir . 'shortcodes/js/olympus_googlemap.js', array('jquery'), '1.0', true );
		wp_register_script( 'olympus_googlemap_api', 'https://maps.googleapis.com/maps/api/js?sensor=false', array('jquery'), '1.0', true );

		// Enqueue CSS
		wp_enqueue_style( 'olympus_shortcode_styles', $scripts_dir . 'shortcodes/css/olympus_shortcodes_styles.css' );
		
	}
	add_action('wp_enqueue_scripts', 'olympus_shortcodes_scripts');
endif;


 

class Olympus_Newsletter {
	 
	/*--------------------------------------------*
	 * Constructor
	 *--------------------------------------------*/
	
	/**
	 * Initializes the plugin by setting localization, filters, and administration functions.
	 */
	function __construct() {
		
		// Register site styles and scripts
		add_action( 'wp_enqueue_scripts', array( &$this, 'register_plugin_styles' ) );
		add_action( 'wp_enqueue_scripts', array( &$this, 'register_plugin_scripts' ) );
		
		// Include the Ajax library on the front end
		add_action( 'wp_head', array( &$this, 'add_ajax_library' ) );
		
		// Setup the event handler for marking this post as read for the current user
		add_action( 'wp_ajax_mark_as_read', array( &$this, 'mark_as_read' ) );
		

	} // end constructor
	
	/*--------------------------------------------*
	 * Action Functions
	 *--------------------------------------------*/
	/**
	 * Adds the WordPress Ajax Library to the frontend.
	 */
	public function add_ajax_library() {
		
		$html = '<script type="text/javascript">';
			$html .= 'var ajaxurl = "' . admin_url( 'admin-ajax.php' ) . '"';
		$html .= '</script>';
		
		echo $html;	
		
	} // end add_ajax_library
	/**
	 * Registers and enqueues plugin-specific styles.
	 */
	public function register_plugin_styles() {
	
		wp_register_style( 'olympus_newsletter', plugins_url( 'olympus-toolkit/widgets/newsletter/newsletter.css' ) );
		wp_enqueue_style( 'olympus_newsletter' );
	
	} // end register_plugin_styles
	
	/**
	 * Registers and enqueues plugin-specific scripts.
	 */
	public function register_plugin_scripts() {
	
		wp_register_script( 'olympus_newsletter', plugins_url( 'olympus-toolkit/widgets/newsletter/js/newsletter.js' ), array( 'jquery' ) );
		wp_enqueue_script( 'olympus_newsletter' );
	
	} // end register_plugin_scripts
	
	/**
	 * Uses the current user ID and the incoming post ID to mark this post as read
	 * for the current user.
	 *
	 * We store this post's ID in the associated user's meta so that we can hide it
	 * from displaying in the list later.
	 */
	public function mark_as_read() {
		
		if( isset( $_POST['email_address'] ) ) {
			
			$email_address = $_POST['email_address'];
			$list_id = $_POST['list_id'];

			$option = get_option('olympus_newsletter');
			$api_key = $option['mailchimp_api_key'];

			require_once( plugin_dir_path(__FILE__) . 'widgets/api/mailchimp/MailChimp.php');	

			$MailChimp = new MailChimp($api_key);

			$result = $MailChimp->call('lists/subscribe', array(
					'id'                => $list_id,
					'email'             => array('email'=> $email_address),
				        'update_existing'   => true,
				));
			
				echo json_encode($result);
		
		}
			
		die();
		
	} // end mark_as_read
	

  
} // end class
new Olympus_Newsletter();

require_once('wp-updates-plugin.php');
new WPUpdatesPluginUpdater_777( 'http://wp-updates.com/api/2/plugin', plugin_basename(__FILE__));

?>