<?php

if ( ! defined( 'ABSPATH' ) ) { 
    exit; // Exit if accessed directly
}

/*
 * Allow shortcodes in widgets
 * @since v1.0
 */
add_filter('widget_text', 'do_shortcode');

/*
 * Fix Shortcodes
 * @since v1.0
 */
if( !function_exists('olympus_fix_shortcodes') ) {
	function olympus_fix_shortcodes($content){
		$array = array (
			'<p>['		=> '[', 
			']</p>'		=> ']', 
			']<br />'	=> ']'
		);
		$content = strtr($content, $array);
		return $content;
	}
}
add_filter('the_content', 'olympus_fix_shortcodes');


/*
 * Clear Floats
 * @since v1.0
 */
if( !function_exists('olympus_clear_floats_shortcode') ) {
	function olympus_clear_floats_shortcode() {
		return '<div class="olympus-clear-floats"></div>';
	}
}
add_shortcode( 'olympus_clear_floats', 'olympus_clear_floats_shortcode' );


/*
 * Callout
 * @since v1.4
 */
if( !function_exists('olympus_callout_shortcode') ) {
	function olympus_callout_shortcode( $atts, $content = NULL ) {
		extract( shortcode_atts( array(
			'caption'				=> '',
			'button_text'			=> '',
			'button_color'			=> 'blue',
			'button_url'			=> 'http://olympusthemes.com',
			'button_target'			=> 'blank',
			'button_border_radius'	=> '',
			'button_size'			=> '',
			'class'					=> '',
			'visibility'			=> 'all',
		), $atts ) );
		$border_radius_style = ( $button_border_radius ) ? 'style="border-radius:'. intval($button_border_radius) .'px"' : NULL;
		$output = '<div class="olympus-callout olympus-clearfix '. $class .' olympus-'. $visibility .'">';
		if ( $button_text !== '' ) {
			$output .= '<div class="olympus-callout-button">';
				$output .='<a href="'. esc_url($button_url) .'" title="'. $button_text .'" target="_'. $button_target .'" class="olympus-button '. $button_size .' '.$button_color .'" '. $border_radius_style .'><span class="olympus-button-inner" '. $border_radius_style .'>';
				$output .= $button_text;
			$output .='</span></a>';
			$output .='</div>';
		}
		$output .= '<div class="olympus-callout-caption">';
			$output .= do_shortcode ( $content );
		$output .= '</div>';
		$output .= '</div>';
		
		return $output;
	}
}
add_shortcode( 'olympus_callout', 'olympus_callout_shortcode' );



/*
 * Spacing
 * @since v1.0
 */
if( !function_exists('olympus_spacing_shortcode') ) {
	function olympus_spacing_shortcode( $atts ) {
		extract( shortcode_atts( array(
			'size'	=> '20px',
			'class'	=> '',
		),
		$atts ) );
	 return '<hr class="olympus-spacing '. $class .'" style="height: '. intval($size) .'px" />';
	}
}
add_shortcode( 'olympus_spacing', 'olympus_spacing_shortcode' );

/**
* Social Icons
* @since 1.0
*/
if( !function_exists('olympus_social_shortcode') ) {
	function olympus_social_shortcode( $atts ){   
		extract( shortcode_atts( array(
			'icon'				=> 'twitter',
			'url'				=> 'http://www.twitter.com/',
			'title'				=> 'Follow Us',
			'target'			=> 'self',
			'border_radius'		=> '',
			'class'				=> '',
		), $atts ) );
		$icons_url = plugin_dir_url( __FILE__ ) .'images/social/';
		$icons_url = apply_filters( 'olympus_social_icon_url', $icons_url );
		return '<a href="' . esc_url($url) . '" class="olympus-social-icon '. $class .'" target="_'.$target.'" title="'. $title .'"><img src="'. $icons_url . $icon .'-round.png" alt="'. $icon .'" /></a>';
	}
}
add_shortcode('olympus_social', 'olympus_social_shortcode');

/**
* Highlights
* @since 1.0
*/
if ( !function_exists( 'olympus_highlight_shortcode' ) ) {
	function olympus_highlight_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'color'			=> 'yellow',
			'class'			=> '',
			'visibility'	=> 'all',
		),
		$atts ) );
		return '<span class="olympus-highlight olympus-highlight-'. $color .' '. $class .' olympus-'. $visibility .'">' . do_shortcode( $content ) . '</span>';
	
	}
}
add_shortcode('olympus_highlight', 'olympus_highlight_shortcode');


/*
 * Buttons
 * @since v1.0
 */
if( !function_exists('olympus_button_shortcode') ) {
	function olympus_button_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'color'				=> 'blue',
			'url'				=> 'http://originalthemes.co',
			'title'				=> 'Visit Site',
			'target'			=> 'self',
			'size'				=> '',
			'border_radius'		=> '',
			'class'				=> '',
			'visibility'		=> 'all',
		), $atts ) );
		
		
		$border_radius_style = ( $border_radius ) ? 'style="border-radius:'. $border_radius .'"' : NULL;
		
		$button = NULL;
		$button .= '<a href="' . $url . '" class="olympus-button '. $size .' ' . $color . ' '. $class .' olympus-'. $visibility .'" target="_'.$target.'" title="'. $title .'" '. $border_radius_style .'>';
			$button .= '<span class="olympus-button-inner" '.$border_radius_style.'>';

				$button .= $content;

			$button .= '</span>';
		$button .= '</a>';
		return $button;
	}
}
add_shortcode('olympus_button', 'olympus_button_shortcode');



/*
 * Boxes
 * @since v1.0
 *
 */
if( !function_exists('olympus_box_shortcode') ) { 
	function olympus_box_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'color'				=> 'gray',
			'float'				=> 'center',
			'text_align'		=> 'left',
			'width'				=> '100%',
			'margin_top'		=> '',
			'margin_bottom'		=> '',
			'class'				=> '',
			'visibility'		=> 'all',
		), $atts ) );
		$style_attr = '';
		if( $margin_bottom ) {
			$style_attr .= 'margin-bottom: '. $margin_bottom .';';
		}
		if ( $margin_top ) {
			$style_attr .= 'margin-top: '. $margin_top .';';
		}
		$alert_content = '';
		$alert_content .= '<div class="olympus-box  ' . $color . ' '.$float.' '. $class .' olympus-'. $visibility .'" style="text-align:'. $text_align .'; width:'. $width .';'. $style_attr .'">';
		$alert_content .= ' '. do_shortcode($content) .'</div>';
		return $alert_content;
	}
}
add_shortcode( 'olympus_box', 'olympus_box_shortcode' );



/*
 * Columns
 * @since v1.0
 *
 */
if( !function_exists('olympus_column_shortcode') ) {
	function olympus_column_shortcode( $atts, $content = null ){
		extract( shortcode_atts( array(
			'size'			=> 'one-third',
			'position'		=>'first',
			'class'			=> '',
			'visibility'	=> 'all',
		), $atts ) );
		return '<div class="olympus-column olympus-' . $size . ' olympus-column-'.$position.' '. $class .' olympus-'. $visibility .'">' . do_shortcode($content) . '</div>';
	}
}
add_shortcode('olympus_column', 'olympus_column_shortcode');



/*
 * Toggle
 * @since v1.0
 */
if( !function_exists('olympus_toggle_shortcode') ) {
	function olympus_toggle_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'title'			=> 'Toggle Title',
			'class'			=> '',
			'visibility'	=> 'all',
		), $atts ) );
		
		// Enque scripts
		wp_enqueue_script('olympus_toggle');
		
		// Display the Toggle
		return '<div class="olympus-toggle '. $class .' olympus-'. $visibility .'"><h3 class="olympus-toggle-trigger">'. $title .'</h3><div class="olympus-toggle-container">' . do_shortcode($content) . '</div></div>';
	}
}
add_shortcode('olympus_toggle', 'olympus_toggle_shortcode');


/*
 * Accordion
 * @since v1.0
 *
 */

// Main
if( !function_exists('olympus_accordion_main_shortcode') ) {
	function olympus_accordion_main_shortcode( $atts, $content = null  ) {
		
		extract( shortcode_atts( array(
			'class'			=> '',
			'visibility'	=> 'all',
		), $atts ) );
		
		// Enque scripts
		wp_enqueue_script('jquery-ui-accordion');
		wp_enqueue_script('olympus_accordion');
		
		// Display the accordion	
		return '<div class="olympus-accordion '. $class .' olympus-'. $visibility .'">' . do_shortcode($content) . '</div>';
	}
}
add_shortcode( 'olympus_accordion', 'olympus_accordion_main_shortcode' );


// Section
if( !function_exists('olympus_accordion_section_shortcode') ) {
	function olympus_accordion_section_shortcode( $atts, $content = null  ) {
		extract( shortcode_atts( array(
			'title'	=> 'Title',
			'class'	=> '',
		), $atts ) );
		return '<h3 class="olympus-accordion-trigger '. $class .'"><a href="#">'. $title .'</a></h3><div>' . do_shortcode($content) . '</div>';
	}
}
add_shortcode( 'olympus_accordion_section', 'olympus_accordion_section_shortcode' );


/*
 * Tabs
 * @since v1.0
 *
 */
if (!function_exists('olympus_tabgroup_shortcode')) {
	function olympus_tabgroup_shortcode( $atts, $content = null ) {
		
		//Enque scripts
		wp_enqueue_script('jquery-ui-tabs');
		wp_enqueue_script('olympus_tabs');
		
		// Display Tabs
		$defaults = array();
		extract( shortcode_atts( $defaults, $atts ) );
		preg_match_all( '/tab title="([^\"]+)"/i', $content, $matches, PREG_OFFSET_CAPTURE );
		$tab_titles = array();
		if( isset($matches[1]) ){ $tab_titles = $matches[1]; }
		$output = '';
		if( count($tab_titles) ){
		    $output .= '<div id="olympus-tab-'. rand(1, 100) .'" class="olympus-tabs">';
			$output .= '<ul class="ui-tabs-nav olympus-clearfix">';
			foreach( $tab_titles as $tab ){
				$output .= '<li><a href="#olympus-tab-'. sanitize_title( $tab[0] ) .'">' . $tab[0] . '</a></li>';
			}
		    $output .= '</ul>';
		    $output .= do_shortcode( $content );
		    $output .= '</div>';
		} else {
			$output .= do_shortcode( $content );
		}
		return $output;
	}
}
add_shortcode( 'olympus_tabgroup', 'olympus_tabgroup_shortcode' );

if (!function_exists('olympus_tab_shortcode')) {
	function olympus_tab_shortcode( $atts, $content = null ) {
		$defaults = array(
			'title'			=> 'Tab',
			'class'			=> '',
			'visibility'	=> 'all',
		);
		extract( shortcode_atts( $defaults, $atts ) );
		return '<div id="olympus-tab-'. sanitize_title( $title ) .'" class="tab-content '. $class .' olympus-'. $visibility .'">'. do_shortcode( $content ) .'</div>';
	}
}
add_shortcode( 'olympus_tab', 'olympus_tab_shortcode' );



/*
 * Slider
 * @since v1.0
 *
 */

if (!function_exists('olympus_slider_shortcode')) {
	function olympus_slider_shortcode( $atts, $content = null ) {

		wp_enqueue_script('rslides');
		
		return '<div class="olympus-slider-container"><ul class="olympus-slider">'. do_shortcode( $content ) .'</ul></div>';
	}
}
add_shortcode( 'olympus_slider', 'olympus_slider_shortcode' );

if (!function_exists('olympus_slide_shortcode')) {
	function olympus_slide_shortcode( $atts, $content = null ) {
		$defaults = array(
			'img'			=> 'http://example.com',
		);
		extract( shortcode_atts( $defaults, $atts ) );
		return '<li><img src="'. $img .'" /></li>';
	}
}
add_shortcode( 'olympus_slide', 'olympus_slide_shortcode' );

/*
 * Heading
 * @since v1.1
 */
if( !function_exists('olympus_heading_shortcode') ) {
	function olympus_heading_shortcode( $atts ) {
		extract( shortcode_atts( array(
			'title'			=> __('Sample Heading', 'olympus-toolkit'),
			'type'			=> 'h2',
			'style'			=> 'double-line',
			'margin_top'	=> '',
			'margin_bottom'	=> '',
			'text_align'	=> '',
			'font_size'		=> '',
			'color'			=> '',
			'class'			=> ''
		),
		$atts ) );


		$style_attr = '';
		if ( $font_size ) {
			$style_attr .= 'font-size: '. $font_size .';';
		}
		if ( $color ) {
			$style_attr .= 'color: '. $color .';';
		}
		if( $margin_bottom ) {
			$style_attr .= 'margin-bottom: '. intval($margin_bottom) .'px;';
		}
		if ( $margin_top ) {
			$style_attr .= 'margin-top: '. intval($margin_top) .'px;';
		}
		
		if ( $text_align ) {
			$text_align = 'text-align-'. $text_align;
		} else {
			$text_align = 'text-align-left';
		}
		
	 	$output = '<'.$type.' class="olympus-heading olympus-heading-'. $style .' '. $text_align .' '. $class .'" style="'.$style_attr.'"><span>';
			$output .= $title;
		$output .= '</'.$type.'></span>';
		
		return $output;
	}
}
add_shortcode( 'olympus_heading', 'olympus_heading_shortcode' );


/*
 * Google Maps
 * @since v1.1
 */
if (! function_exists( 'olympus_shortcode_googlemaps' ) ) {
	function olympus_shortcode_googlemaps($atts, $content = null) {
		
		extract(shortcode_atts(array(
				'title'			=> '',
				'location'		=> '',
				'width'			=> '',
				'height'		=> '300',
				'zoom'			=> 8,
				'align'			=> '',
				'class'			=> '',
				'visibility'	=> 'all',
		), $atts));
		
		// load scripts
		wp_enqueue_script('olympus_googlemap');
		wp_enqueue_script('olympus_googlemap_api');
		
		
		$output = '<div id="map_canvas_'.rand(1, 100).'" class="googlemap '. $class .' olympus-'. $visibility .'" style="height:'.$height.'px;width:100%">';
			$output .= (!empty($title)) ? '<input class="title" type="hidden" value="'.$title.'" />' : '';
			$output .= '<input class="location" type="hidden" value="'.$location.'" />';
			$output .= '<input class="zoom" type="hidden" value="'.$zoom.'" />';
			$output .= '<div class="map_canvas"></div>';
		$output .= '</div>';
		
		return $output;
	}
}
add_shortcode("olympus_googlemap", "olympus_shortcode_googlemaps");


/*
 * Divider
 * @since v1.1
 */
if( !function_exists('olympus_divider_shortcode') ) {
	function olympus_divider_shortcode( $atts ) {
		extract( shortcode_atts( array(
			'style'				=> 'fadeout',
			'margin_top'		=> '20px',
			'margin_bottom'		=> '20px',
			'class'				=> '',
			'visibility'		=> 'all',
		),
		$atts ) );
		$style_attr = '';
		if ( $margin_top && $margin_bottom ) {  
			$style_attr = 'style="margin-top: '. intval($margin_top) .'px;margin-bottom: '. intval($margin_bottom) .'px;"';
		} elseif( $margin_bottom ) {
			$style_attr = 'style="margin-bottom: '. intval($margin_bottom) .'px;"';
		} elseif ( $margin_top ) {
			$style_attr = 'style="margin-top: '. intval($margin_top) .'px;"';
		} else {
			$style_attr = NULL;
		}
	 return '<hr class="olympus-divider '. $style .' '. $class .' olympus-'. $visibility .'" '.$style_attr.' />';
	}
}
add_shortcode( 'olympus_divider', 'olympus_divider_shortcode' );



    add_shortcode('fa', 'fa_function');


function fa_function($atts, $content = null) {
  	$atts = shortcode_atts( array(
        "type" => ''
	), $atts );
    $class  = 'fa';
    $class .= ( $atts['type'] )         ? ' fa-' . $atts['type'] : '';

      
    return sprintf( 
      '<i class="%s"></i>',
      esc_attr( $class )
    );
}