<?php

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init',
     create_function('', 'register_widget("Olympus_Profile_Widget");')
);

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class Olympus_Profile_Widget extends WP_Widget {


/*-----------------------------------------------------------------------------------*/
/*	Widget Setup
/*-----------------------------------------------------------------------------------*/


	public function __construct() {
				parent::__construct(
			'olympus_profile_widget', // Base ID
			__('Olympus Author Widget', 'olympus-toolkit'), // Name
			array( 'description' => __( 'A Simple Author Widget', 'olympus-toolkit' ), ) // Args
		);
	}

/*-----------------------------------------------------------------------------------*/
/*	Display Widget
/*-----------------------------------------------------------------------------------*/
	
public function widget( $args, $instance ) {
	extract( $args );

	/* Our variables from the widget settings --------------------------------------*/
	$widget_title = apply_filters('widget_title', $instance['widget_title'] );
	$widget_desc =  $instance['widget_desc'];
	$author_image =  $instance['author_image'];

	
    /* Display widget -------------------------------------------------------------*/
	echo $before_widget;

	if ( $widget_title ) { echo $before_title . $widget_title . $after_title; }

	if(! empty($author_image)) {
 		echo	'<img class="olympus-author-image" src="'.$author_image.'"/>';
	}	
	
	if (!empty($widget_desc)) {
		
		echo '<div class="widget-description">'.wpautop($widget_desc).'</div>';

	} 
	
	echo $after_widget;
}


/*------------------------------------------------------------------------------*/
/*	Widget Settings (Displays the widget settings controls on the widget panel)
/*------------------------------------------------------------------------------*/
	
public function form( $instance ) {

	// Get the options into variables, escaping html characters on the way
	$widget_title = isset( $instance['widget_title'] ) ? esc_attr( $instance['widget_title'] ) : 'About Me';
	$widget_desc = isset( $instance['widget_desc'] ) ? esc_attr( $instance['widget_desc'] ) : '';
	$author_image = isset( $instance['author_image'] ) ? esc_url( $instance['author_image'] ) : '';
	
	/* Build our form fields --------------------------------------------------*/
	?>

	<p>
		<label for="<?php echo $this->get_field_id( 'widget_title' ); ?>"><?php _e('Title:', 'olympus-toolkit') ?></label>
		<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_title' ); ?>" name="<?php echo $this->get_field_name( 'widget_title' ); ?>" value="<?php echo $widget_title; ?>" />
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('widget_desc'); ?>"><?php _e('Widget Text:', 'olympus-toolkit'); ?></label>
		<textarea class="widefat" id="<?php echo $this->get_field_id('widget_desc'); ?>" name="<?php echo $this->get_field_name('widget_desc'); ?>" rows="5" cols="20" ><?php echo $widget_desc; ?></textarea>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'author_image' ); ?>"><?php _e('Your Image URL:', 'olympus-toolkit') ?></label>
		<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'author_image' ); ?>" name="<?php echo $this->get_field_name( 'author_image' ); ?>" placeholder="http://" value="<?php echo $author_image; ?>" />
	</p>

	
	<?php
	}


/*--------------------------------------------------------------------------------*/
/*	Update Widget
/*--------------------------------------------------------------------------------*/
	
public function update( $new_instance, $old_instance ) {
	$instance = $old_instance;

	/* Strip tags to remove HTML (important for text inputs) ---------------------*/
	$instance['widget_title'] = strip_tags( $new_instance['widget_title'] );

	$instance['author_image'] = esc_url($new_instance['author_image']);
	$instance['widget_desc'] = $new_instance['widget_desc'];
	
	return $instance;
}
	
}