<?php

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init',
     create_function('', 'register_widget("Olympus_Featured_Posts_Widget");')
);

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class Olympus_Featured_Posts_Widget extends WP_Widget {


/*-----------------------------------------------------------------------------------*/
/*	Widget Setup
/*-----------------------------------------------------------------------------------*/


	public function __construct() {
				parent::__construct(
			'olympus_featured_posts_widget', // Base ID
			__('Olympus Featured Posts Widget', 'olympus-toolkit'), // Name
			array( 'description' => __( 'Display your most important posts.', 'olympus-toolkit' ), ) // Args
		);
	}

/*-----------------------------------------------------------------------------------*/
/*	Display Widget
/*-----------------------------------------------------------------------------------*/
	
public function widget( $args, $instance ) {
	extract( $args );

	/* Our variables from the widget settings --------------------------------------*/
	$widget_title = apply_filters('widget_title', $instance['widget_title'] );
	$widget_desc =  $instance['widget_desc'];
	$post_count =  $instance['post_count'];

	
    /* Display widget -------------------------------------------------------------*/
	echo $before_widget;

	if ( $widget_title ) { echo $before_title . $widget_title . $after_title; }

	if (!empty($widget_desc)) {
		
		echo '<div class="widget-description">'.wpautop($widget_desc).'</div>';

	} 	
	
	olympus_featured_post_loop($post_count);
	
	echo $after_widget;
}


/*------------------------------------------------------------------------------*/
/*	Widget Settings (Displays the widget settings controls on the widget panel)
/*------------------------------------------------------------------------------*/
	
public function form( $instance ) {

	// Get the options into variables, escaping html characters on the way
	$widget_title = isset( $instance['widget_title'] ) ? esc_attr( $instance['widget_title'] ) : 'Featured Posts';
	$widget_desc = isset( $instance['widget_desc'] ) ? esc_attr( $instance['widget_desc'] ) : '';
	$post_count = isset( $instance['post_count'] ) ? esc_attr( $instance['post_count'] ) : '5';
	
	/* Build our form fields --------------------------------------------------*/
	?>
	<p>Add your posts to a category named 'featured' to make them display in this widget.</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'widget_title' ); ?>"><?php _e('Title:', 'olympus-toolkit') ?></label>
		<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_title' ); ?>" name="<?php echo $this->get_field_name( 'widget_title' ); ?>" value="<?php echo $widget_title; ?>" />
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('widget_desc'); ?>"><?php _e('Widget Text:', 'olympus-toolkit'); ?></label>
		<textarea class="widefat" id="<?php echo $this->get_field_id('widget_desc'); ?>" name="<?php echo $this->get_field_name('widget_desc'); ?>" rows="5" cols="20" ><?php echo $widget_desc; ?></textarea>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'post_count' ); ?>"><?php _e('Show how many posts?:', 'olympus-toolkit') ?></label>
		<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'post_count' ); ?>" name="<?php echo $this->get_field_name( 'post_count' ); ?>" value="<?php echo $post_count; ?>" />
	</p>

	
	<?php
	}


/*--------------------------------------------------------------------------------*/
/*	Update Widget
/*--------------------------------------------------------------------------------*/
	
public function update( $new_instance, $old_instance ) {
	
	$instance = $old_instance;

	/* Strip tags to remove HTML (important for text inputs) ---------------------*/
	$instance['widget_title'] = strip_tags( $new_instance['widget_title'] );
	$instance['post_count'] = esc_attr($new_instance['post_count']);
	$instance['widget_desc'] = $new_instance['widget_desc'];
	
	return $instance;
}
	
}

function olympus_featured_post_loop($post_count = 5) {

	query_posts( 'category_name=featured&posts_per_page='.$post_count ); ?>

	<?php if ( have_posts() ) : while ( have_posts() ) : the_post(); ?>

		<div class="olympus-featured-post clearfix">

			<?php if ( has_post_thumbnail() ) {
				the_post_thumbnail('featured-widget');
			} ?>
			
			<div class="olympus-post-title">
				
				<h6><a href="<?php the_permalink(); ?>" rel="bookmark" title="Permanent Link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a></h6>

				<div class="olympus-post-date"><?php the_time('F jS, Y'); ?></div>
			</div>
			
		</div> 

	 <?php endwhile; else : ?>

		<p><?php _e( 'Add your post to the \'featured\' category to have them display here.', 'olympus-toolkit' ); ?></p>

	 <?php endif; ?>


<?php }