<?php

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init',
     create_function('', 'register_widget("Olympus_Flickr_Widget");')
);

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class Olympus_Flickr_Widget extends WP_Widget {


/*-----------------------------------------------------------------------------------*/
/*	Widget Setup
/*-----------------------------------------------------------------------------------*/


	public function __construct() {
				parent::__construct(
			'olympus_flickr_widget', // Base ID
			__('Olympus Flickr Widget', 'olympus-toolkit'), // Name
			array( 'description' => __( 'A Simple Flickr Widget', 'olympus-toolkit' ), ) // Args
		);
	}

/*-----------------------------------------------------------------------------------*/
/*	Display Widget
/*-----------------------------------------------------------------------------------*/
	
public function widget( $args, $instance ) {
	extract( $args );

	/* Our variables from the widget settings --------------------------------------*/
	$widget_title = apply_filters('widget_title', $instance['widget_title'] );
	$widget_desc =  $instance['widget_desc'];
	$flickr_id =  esc_attr($instance['flickr_id']);

	
    /* Display widget -------------------------------------------------------------*/
	echo $before_widget;

	if ( $widget_title ) { echo $before_title . $widget_title . $after_title; }

	if (!empty($widget_desc)) {
		
			echo '<div class="widget-description">'.wpautop($widget_desc).'</div>';

	} 
	
	if(! empty($flickr_id)) {
 		echo	'<div id="flickr_badge_wrapper"><script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count=6&display=latest&size=m&layout=x&source=user&user='.$flickr_id.'"></script></div>';
	}
	
	echo $after_widget;
}


/*------------------------------------------------------------------------------*/
/*	Widget Settings (Displays the widget settings controls on the widget panel)
/*------------------------------------------------------------------------------*/
	
public function form( $instance ) {

	// Get the options into variables, escaping html characters on the way
	$widget_title = isset( $instance['widget_title'] ) ? esc_attr( $instance['widget_title'] ) : 'Flickr Feed';
	$widget_desc = isset( $instance['widget_desc'] ) ? esc_attr( $instance['widget_desc'] ) : '';
	$flickr_id = isset( $instance['flickr_id'] ) ? esc_attr( $instance['flickr_id'] ) : '';
	
	/* Build our form fields --------------------------------------------------*/
	?>
	<p>Get your Flickr ID here: <a href="http://idgettr.com/">http://idgettr.com</a></p>

	<p>
		<label for="<?php echo $this->get_field_id( 'widget_title' ); ?>"><?php _e('Title:', 'olympus-toolkit') ?></label>
		<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'widget_title' ); ?>" name="<?php echo $this->get_field_name( 'widget_title' ); ?>" value="<?php echo $widget_title; ?>" />
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('widget_desc'); ?>"><?php _e('Widget Text:', 'olympus-toolkit'); ?></label>
		<textarea class="widefat" id="<?php echo $this->get_field_id('widget_desc'); ?>" name="<?php echo $this->get_field_name('widget_desc'); ?>" rows="5" cols="20" ><?php echo $widget_desc; ?></textarea>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'flickr_id' ); ?>"><?php _e('Flickr ID:', 'olympus-toolkit') ?></label>
		<input class="widefat" type="text" id="<?php echo $this->get_field_id( 'flickr_id' ); ?>" name="<?php echo $this->get_field_name( 'flickr_id' ); ?>" value="<?php echo $flickr_id; ?>" />
	</p>

	
	<?php
	}


/*--------------------------------------------------------------------------------*/
/*	Update Widget
/*--------------------------------------------------------------------------------*/
	
public function update( $new_instance, $old_instance ) {
	
	$instance = $old_instance;

	/* Strip tags to remove HTML (important for text inputs) ---------------------*/
	$instance['widget_title'] = strip_tags( $new_instance['widget_title'] );
	$instance['widget_desc'] = $new_instance['widget_desc'];
	$instance['flickr_id'] = esc_attr($new_instance['flickr_id']);
	
	return $instance;
}
	
}