<?php 

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init',
     create_function('', 'register_widget("Olympus_Newsletter_Widget");')
);

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
class Olympus_Newsletter_Widget extends WP_Widget {

/*-----------------------------------------------------------------------------------*/
/*	Widget Setup
/*-----------------------------------------------------------------------------------*/


	public function __construct() {
				parent::__construct(
			'olympus_newsletter_widget', // Base ID
			__('Olympus Newsletter Widget', 'olympus-toolkit'), // Name
			array( 'description' => __( 'A Simple Newsletter Widget', 'olympus-toolkit' ), ) // Args
		);
	}

/*-----------------------------------------------------------------------------------*/
/*	Display Widget
/*-----------------------------------------------------------------------------------*/	
	
	public function widget($args, $instance) {
	
		// Outputs the content of the widget
		extract($args); // Make before_widget, etc available.
		
		$widget_title = apply_filters('widget_title', $instance['widget_title']);
		$widget_desc = $instance['widget_desc'];
		$list_id = $instance['newsletter_list'];
		
		echo $before_widget;
		
		if (!empty($widget_title)) {
		
			echo $before_title . $widget_title . $after_title;
			
		} 
			
			if (!empty($widget_desc)) {
			
				echo '<div class="widget-description">'.wpautop($widget_desc).'</div>';
				
			} 
		?>

		<form id="olympus-submit">
			<div id="result"></div>
			<div id="error"></div>
			<input id="list_id" type="hidden" value="<?php echo $list_id ?>">
			<input id="email_address" type="text" placeholder="Your Email Address..." value="">
			<input id="newsletter-submit" type="submit" value="Subscribe">
		</form>

			<?php

		echo $after_widget; 
	}
	
/*------------------------------------------------------------------------------*/
/*	Widget Settings (Displays the widget settings controls on the widget panel)
/*------------------------------------------------------------------------------*/
	
	public function form($instance) {
	
		// Get the options into variables, escaping html characters on the way
		$widget_title = isset( $instance['widget_title'] ) ? esc_attr( $instance['widget_title'] ) : '';
		$widget_desc = isset( $instance['widget_desc'] ) ? $instance['widget_desc'] : '';
		$newsletter_list = isset( $instance['newsletter_list'] ) ? esc_attr( $instance['newsletter_list'] ) : '';
		$mailchimp_lists = get_mailchimp_lists();
		$settings_url = admin_url( 'options-general.php?page=olympus_toolkit' );
		?>

	<?php if( empty($mailchimp_lists) ) : ?>
		  <p><?php _e('Please check you have entered your API key in the <a href="'.$settings_url.'">Olympus Toolkit Options Panel</a>.', 'olympus-toolkit'); ?></p>
	<?php endif;?>

	<p>
		<label for="<?php echo $this->get_field_id('widget_title'); ?>">
			<?php _e( 'Newsletter Heading', 'olympus-toolkit'); ?>:
			<input id="<?php echo $this->get_field_id('widget_title'); ?>" name="<?php echo $this->get_field_name('widget_title'); ?>" type="text" class="widefat" value="<?php echo $widget_title; ?>" />
		</label>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('widget_desc'); ?>">
			<?php _e( 'Newsletter Description', 'olympus-toolkit'); ?>:
			<textarea id="<?php echo $this->get_field_id('widget_desc'); ?>" name="<?php echo $this->get_field_name('widget_desc'); ?>" type="text" class="widefat"><?php echo $widget_desc; ?></textarea>
		</label>
	</p>

		<p>
			<label for="<?php echo $this->get_field_id('newsletter_list'); ?>"><?php _e('Newsletter List:', 'olympus-toolkit'); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id('newsletter_list'); ?>" name="<?php echo $this->get_field_name('newsletter_list'); ?>">

				<?php

				foreach($mailchimp_lists as $list){ ?>

					<option <?php is_active_newsletter( $newsletter_list, $list['id'] ); ?> value="<?php echo $list['id']; ?>">
					<?php echo $list['name']; ?>
					</option>

				<?php } ?>
				
			</select>
		</p>
						
		<?php
	}
	
/*--------------------------------------------------------------------------------*/
/*	Update Widget
/*--------------------------------------------------------------------------------*/
	
		public function update($new_instance, $old_instance) {
	
			$instance = $old_instance;

	/* Strip tags to remove HTML (important for text inputs) ---------------------*/
	$instance['widget_title'] = strip_tags( $new_instance['widget_title'] );
	$instance['widget_desc'] = $new_instance['widget_desc'];
	$instance['newsletter_list'] = esc_attr($new_instance['newsletter_list']);
	
	return $instance;
		
	}
	
	
}

function get_mailchimp_lists() {
	require_once( plugin_dir_path(__FILE__) . 'api/mailchimp/MailChimp.php');
	
	$option = get_option('olympus_newsletter');
	
	if (isset($option['mailchimp_api_key'])) {
		$api_key = $option['mailchimp_api_key'];
	
		if($api_key != '') {

			$lists = array();
			$MailChimp = new MailChimp($api_key);
			$result = $MailChimp->call('lists/list');
			if($result['data']) {
				foreach ($result['data'] as $value ) {
					$lists[] = array('id' => $value['id'], 'name' => $value['name']);
				}	
				return $lists;
			}
		}
	}
}

function is_active_newsletter($current_id, $new_id) {
	if ($new_id == $current_id ) echo 'selected';
}


