<?php

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/

add_action('widgets_init',
     create_function('', 'register_widget("Olympus_Social_Widget");')
);

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/

class Olympus_Social_Widget extends WP_Widget {
	
/*-----------------------------------------------------------------------------------*/
/*	Widget Setup
/*-----------------------------------------------------------------------------------*/	
	
function __construct() {

  parent::__construct(
    // Base ID of your widget
    'olympus_social_widget', 

    // Widget name will appear in UI
    __('Olympus Social Profiles', 'olympus-toolkit'), 

    // Widget description
    array( 'description' => __( 'This widget displays the social profiles you entered in the Olympus Toolkit Options Panel.', 'olympus-toolkit' ), ) 
  );
  
}

/*-----------------------------------------------------------------------------------*/
/*	Display Widget
/*-----------------------------------------------------------------------------------*/	
	
// This is where the action happens
public function widget( $args, $instance ) {

  $title = apply_filters( 'widget_title', $instance['title'] );
  $widget_desc = $instance['widget_desc'];
	
  // before and after widget arguments are defined by themes
  echo $args['before_widget'];
  if ( ! empty( $title ) )
  echo $args['before_title'] . $title . $args['after_title'];
	
	echo '<div class="widget-description">'.wpautop($widget_desc).'</div>';

  // This is where you run the code and display the output
  generate_social_links();
  echo $args['after_widget'];
  
}
		
/*------------------------------------------------------------------------------*/
/*	Widget Settings (Displays the widget settings controls on the widget panel)
/*------------------------------------------------------------------------------*/
	
	
public function form( $instance ) {
	
	$settings_url = admin_url( 'options-general.php?page=olympus_toolkit' );

  if ( isset( $instance[ 'title' ] ) ) {
    $title = $instance[ 'title' ];
  }
  else {
    $title = __( 'Social Media', 'olympus-toolkit' );
  }
	$widget_desc = isset( $instance['widget_desc'] ) ? esc_attr( $instance['widget_desc'] ) : '';


	
  // Widget admin form
  ?>
  <p><?php _e('This widget displays the social profiles you entered in the <a href="'.$settings_url.'">Olympus Toolkit Options Panel</a>.', 'olympus-toolkit'); ?></p>

  <p>
  <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'olympus-toolkit' ); ?></label> 
  <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
  </p>

  <p>
  <label for="<?php echo $this->get_field_id( 'widget_desc' ); ?>"><?php _e( 'Widget Text:', 'olympus-toolkit' ); ?></label> 
  <textarea class="widefat" rows="5" cols="20" id="<?php echo $this->get_field_id( 'widget_desc' ); ?>" name="<?php echo $this->get_field_name( 'widget_desc' ); ?>" type="text"><?php echo $widget_desc; ?></textarea>
  </p>

<?php 
}
	
/*--------------------------------------------------------------------------------*/
/*	Update Widget
/*--------------------------------------------------------------------------------*/
	
	
public function update( $new_instance, $old_instance ) {

	$instance = $old_instance;
	$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
	$instance['widget_desc'] = ( ! empty( $new_instance['widget_desc'] ) ) ? strip_tags( $new_instance['widget_desc'] ) : '';
	return $instance;

}
 
} // Class author_widget ends here


function generate_social_links() {

	$social_settings = get_option('olympus_social');
	
  echo '<ul id="social-widget">';

	$social_profiles = array(
		'500px',
		'apple',
		'behance',
		'blogger',
		'buffer',
		'dailymotion',
		'delicious',
		'deviantart',
		'digg',
		'disqus',
		'dribbble',
		'envato',
		'facebook',
		'feedburner',
		'flattr',
		'flickr',
		'forrst',
		'github',
		'google',
		'instagram',
		'linkedin',
		'pinterest',
		'reddit',
		'rss',
		'soundcloud',
		'spotify',
		'stumbleupon',
		'tumblr',
		'twitter',
		'vimeo',
		'wordpress',
		'youtube'
	);

	foreach($social_profiles as $profile) {
		if(isset($social_settings[$profile])) {
		  if( $social_settings[$profile] != 'http://') {
			  echo '<li>
				  <a class="'.$profile.'" href="'.$social_settings[$profile].'">
						<img alt="'.$profile.' profile" src="' . plugins_url( 'shortcodes/images/social/'.$profile.'-round.png', dirname(__FILE__)  ) . '" >
				  </a>
			  </li>'; 
		  }
	}

	}
  echo '</ul>';

}