<?php

/*-----------------------------------------------------------------------------------*/
/*  Create the widget
/*-----------------------------------------------------------------------------------*/
add_action('widgets_init',
     create_function('', 'register_widget("Olympus_Twitter_Widget");')
);

/*-----------------------------------------------------------------------------------*/
/*  Widget class
/*-----------------------------------------------------------------------------------*/
	class Olympus_Twitter_Widget extends WP_Widget {
	
/*-----------------------------------------------------------------------------------*/
/*	Widget Setup
/*-----------------------------------------------------------------------------------*/	
		
		public function __construct() {
			parent::__construct(
				'olympus_twitter_widget', // Base ID
				'Olympus Recent Tweets', // Name
				array( 'description' => __( 'Display your recent tweets', 'olympus-toolkit' ), ) // Args
			);
		}

/*-----------------------------------------------------------------------------------*/
/*	Display Widget
/*-----------------------------------------------------------------------------------*/	
		
		//widget output
			public function widget($args, $instance) {
				extract($args);
				
				$api_keys = get_option('olympus_twitter');
				$title = apply_filters( 'widget_title', $instance['title'] ); 
				
				
				echo $before_widget;			
					
				if ( !empty($title) ){ 
					echo $before_title . $title . $after_title; 
				}

				
				//check settings and die if not set
				if( empty( $api_keys['consumer_key'] ) || empty( $api_keys['consumer_secret'] ) || empty( $api_keys['access_token']) || empty($api_keys['access_token_secret'] ) ) {
					echo '<strong>'.__('Please fill in the API Key settings!','olympus-toolkit').'</strong>' . $after_widget;
					return;
				}
				
				if( empty($instance['cachetime']) || empty($instance['username']) ) {
					echo '<strong>'.__('Please fill in all the widget settings!','olympus-toolkit').'</strong>' . $after_widget;
					return;
				}
					
										
					//check if cache needs update
						$olympus_twitter_plugin_last_cache_time = get_option('olympus_twitter_plugin_last_cache_time');
						$diff = time() - $olympus_twitter_plugin_last_cache_time;
						$crt = $instance['cachetime'] * 3600;
						
					 //	yes, it needs update			
						if($diff >= $crt || empty($olympus_twitter_plugin_last_cache_time)){
							
							if(!require_once('api/twitteroauth/twitteroauth.php')){ 
								echo '<strong>'.__('Couldn\'t find twitteroauth.php!','olympus-toolkit').'</strong>' . $after_widget;
								return;
							}
														
							function getConnectionWithAccessToken($cons_key, $cons_secret, $oauth_token, $oauth_token_secret) {
							  $connection = new TwitterOAuth($cons_key, $cons_secret, $oauth_token, $oauth_token_secret);
							  return $connection;
							}
							  
							  							  
							$connection = getConnectionWithAccessToken($api_keys['consumer_key'], $api_keys['consumer_secret'], $api_keys['access_token'], $api_keys['access_token_secret']);
							$tweets = $connection->get("https://api.twitter.com/1.1/statuses/user_timeline.json?screen_name=".$instance['username']."&count=50&exclude_replies=".$instance['excludereplies']) or die('Couldn\'t retrieve tweets! Wrong username?');
							
														
							if(!empty($tweets->errors)){
								if($tweets->errors[0]->message == 'Invalid or expired token'){
									echo '<strong>'.$tweets->errors[0]->message.'!</strong><br />' . __('You\'ll need to regenerate it <a href="https://dev.twitter.com/apps" target="_blank">here</a>!','olympus-toolkit') . $after_widget;
								}else{
									echo '<strong>'.$tweets->errors[0]->message.'</strong>' . $after_widget;
								}
								return;
							}
							
							$tweets_array = array();
							for($i = 0;$i <= count($tweets); $i++){
								if(!empty($tweets[$i])){
									$tweets_array[$i]['created_at'] = $tweets[$i]->created_at;
									
										//clean tweet text
										$tweets_array[$i]['text'] = preg_replace('/[\x{10000}-\x{10FFFF}]/u', '', $tweets[$i]->text);
									
									if(!empty($tweets[$i]->id_str)){
										$tweets_array[$i]['status_id'] = $tweets[$i]->id_str;			
									}
								}	
							}							
							
							//save tweets to wp option 		
								update_option('olympus_twitter_plugin_tweets',serialize($tweets_array));							
								update_option('olympus_twitter_plugin_last_cache_time',time());
								
							echo '<!-- twitter cache has been updated! -->';
						}
						
						
												
					
					$olympus_twitter_plugin_tweets = maybe_unserialize(get_option('olympus_twitter_plugin_tweets'));
					if(!empty($olympus_twitter_plugin_tweets) && is_array($olympus_twitter_plugin_tweets)){
						print '
						<div class="olympus_recent_tweets">
							<ul>';
							$fctr = '1';
							foreach($olympus_twitter_plugin_tweets as $tweet){					
								if(!empty($tweet['text'])){
									if(empty($tweet['status_id'])){ $tweet['status_id'] = ''; }
									if(empty($tweet['created_at'])){ $tweet['created_at'] = ''; }
								
									print '<li><span>'.olympus_convert_links($tweet['text']).'</span><br /><a class="twitter_time" target="_blank" href="http://twitter.com/'.$instance['username'].'/statuses/'.$tweet['status_id'].'">'.olympus_relative_time($tweet['created_at']).'</a></li>';
									if($fctr == $instance['tweetstoshow']){ break; }
									$fctr++;
								}
							}
						
						print '
							</ul>
							<a href="https://twitter.com/'.$instance['username'].'" class="twitter-follow-button" data-show-count="false">Follow @'.$instance['username'].'</a>
<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?\'http\':\'https\';if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+\'://platform.twitter.com/widgets.js\';fjs.parentNode.insertBefore(js,fjs);}}(document, \'script\', \'twitter-wjs\');</script>
						</div>';
					}else{
						print '
						<div class="olympus_recent_tweets">
							' . __('<b>Error!</b> Couldn\'t retrieve tweets for some reason!','olympus-toolkit') . '
						</div>';
					}
				
				echo $after_widget;
			}
		
			
/*------------------------------------------------------------------------------*/
/*	Widget Settings (Displays the widget settings controls on the widget panel)
/*------------------------------------------------------------------------------*/
		
			public function form($instance) {;
				
				// Get the options into variables, escaping html characters on the way
				$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : 'Twitter Feed';
				$cachetime = isset( $instance['cachetime'] ) ? esc_attr( $instance['cachetime'] ) : '24';
				$username = isset( $instance['username'] ) ? esc_attr( $instance['username'] ) : '';
				$tweetstoshow = isset( $instance['tweetstoshow'] ) ? esc_attr( $instance['tweetstoshow'] ) : '5';
				$excludereplies = isset( $instance['excludereplies'] ) ? esc_attr( $instance['excludereplies'] ) : '';
				$api_keys = get_option('olympus_twitter');		
				$api_settings_url = admin_url( 'options-general.php?page=olympus_toolkit' );
							 
								
											 
				//check settings and die if not set
				if( empty( $api_keys['consumer_key'] ) || empty( $api_keys['consumer_secret'] ) || empty( $api_keys['access_token']) || empty($api_keys['access_token_secret'] ) ) {
					echo '<p><strong>'.__('Please fill in the <a href="'.$api_settings_url.'">API Key settings</a>!','olympus-toolkit').'</strong></p>';
				}							 
											 
				echo '
				<p><label>' . __('Title:','olympus') . '</label>
					<input type="text" name="'.$this->get_field_name( 'title' ).'" id="'.$this->get_field_id( 'title' ).'" value="'.$title.'" class="widefat" /></p>
					<p><label>' . __('Twitter Username:','olympus-toolkit') . '</label>
					<input type="text" name="'.$this->get_field_name( 'username' ).'" id="'.$this->get_field_id( 'username' ).'" value="'.$username.'" class="widefat" /></p>	
				<p><label>' . __('Cache Tweets for:','olympus-toolkit') . '</label>
					<input type="text" name="'.$this->get_field_name( 'cachetime' ).'" id="'.$this->get_field_id( 'cachetime' ).'" value="'.$cachetime.'" class="small-text" /> hours</p>																												
				<p><label>' . __('Tweets to display:','olympus-toolkit') . '</label>
					<select type="text" name="'.$this->get_field_name( 'tweetstoshow' ).'" id="'.$this->get_field_id( 'tweetstoshow' ).'">';
					$i = 1;
					for(i; $i <= 10; $i++){
						echo '<option value="'.$i.'"'; if($tweetstoshow == $i){ echo ' selected="selected"'; } echo '>'.$i.'</option>';						
					}
					echo '
					</select></p>
				<p><label>' . __('Exclude replies:','olympus-toolkit') . '</label>
					<input type="checkbox" name="'.$this->get_field_name( 'excludereplies' ).'" id="'.$this->get_field_id( 'excludereplies' ).'" value="true"'; 
					if(!empty($excludereplies) && $excludereplies == 'true'){
						print ' checked="checked"';
					}					
					print ' /></p>';						

			}
	
/*--------------------------------------------------------------------------------*/
/*	Update Widget
/*--------------------------------------------------------------------------------*/
		
		//save widget settings 
			public function update($new_instance, $old_instance) {				
				$instance = $old_instance;
				$instance['title'] = strip_tags( $new_instance['title'] );
				$instance['cachetime'] = strip_tags( $new_instance['cachetime'] );
				$instance['username'] = strip_tags( $new_instance['username'] );
				$instance['tweetstoshow'] = strip_tags( $new_instance['tweetstoshow'] );
				$instance['excludereplies'] = strip_tags( $new_instance['excludereplies'] );

				if($old_instance['username'] != $new_instance['username']){
					delete_option('olympus_twitter_plugin_last_cache_time');
				}
				
				return $instance;
			}
}


				//convert links to clickable format
					if (!function_exists('olympus_convert_links')) {
						function olympus_convert_links($status,$targetBlank=true,$linkMaxLen=250){
						 
							// the target
								$target=$targetBlank ? " target=\"_blank\" " : "";
							 
							// convert link to url								
								$status = preg_replace('/\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[A-Z0-9+&@#\/%=~_|]/i', '<a href="\0" target="_blank">\0</a>', $status);
							 
							// convert @ to follow
								$status = preg_replace("/(@([_a-z0-9\-]+))/i","<a href=\"http://twitter.com/$2\" title=\"Follow $2\" $target >$1</a>",$status);
							 
							// convert # to search
								$status = preg_replace("/(#([_a-z0-9\-]+))/i","<a href=\"https://twitter.com/search?q=$2\" title=\"Search $1\" $target >$1</a>",$status);
							 
							// return the status
								return $status;
						}
					}
					
					
					//convert dates to readable format	
					if (!function_exists('olympus_relative_time')) {
						function olympus_relative_time($a) {
							//get current timestampt
							$b = strtotime('now'); 
							//get timestamp when tweet created
							$c = strtotime($a);
							//get difference
							$d = $b - $c;
							//calculate different time values
							$minute = 60;
							$hour = $minute * 60;
							$day = $hour * 24;
							$week = $day * 7;
								
							if(is_numeric($d) && $d > 0) {
								//if less then 3 seconds
								if($d < 3) return __('right now','olympus-toolkit');
								//if less then minute
								if($d < $minute) return floor($d) . __(' seconds ago','olympus-toolkit');
								//if less then 2 minutes
								if($d < $minute * 2) return __('about 1 minute ago','olympus-toolkit');
								//if less then hour
								if($d < $hour) return floor($d / $minute) . __(' minutes ago','olympus-toolkit');
								//if less then 2 hours
								if($d < $hour * 2) return __('about 1 hour ago','olympus-toolkit');
								//if less then day
								if($d < $day) return floor($d / $hour) . __(' hours ago','olympus-toolkit');
								//if more then day, but less then 2 days
								if($d > $day && $d < $day * 2) return __('yesterday','olympus-toolkit');
								//if less then year
								if($d < $day * 365) return floor($d / $day) . __(' days ago','olympus-toolkit');
								//else return more than a year
								return __('over a year ago','olympus');
							}
						}	
					}

?>